@@ -8,8 +8,7 @@ from isc_common.fields.code_field import CodeField
 from isc_common.fields.name_field import NameField
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.base_ref import BaseRefHierarcy, BaseRefManager, BaseRefQuerySet
-from isc_common.progress import managed_progress, ProgressDroped
-from kaf_pas.production.models import progress_deleted
+from isc_common.progress import managed_progress, ProgressDroped, progress_deleted
 
 logger = logging.getLogger(__name__)
 
@@ -20,7 +19,6 @@ class AttrQuerySet(BaseRefQuerySet):
 
 class AttrManager(BaseRefManager):
     def deleteFromRequest(self, request, removed=None, ):
-        from isc_common.models.deleted_progresses import Deleted_progresses
         from kaf_pas.kd.models.document_attr_cross import Document_attr_cross
         from kaf_pas.kd.models.document_attributes import Document_attributes
         from kaf_pas.kd.models.lotsman_document_attr_cross import Lotsman_document_attr_cross
@@ -40,26 +38,22 @@ class AttrManager(BaseRefManager):
                         title='Удаление атрибута(ов)',
                         props=TurnBitOn(0, 0)
                 ) as progress:
-                    try:
-                        with transaction.atomic():
-                            progress.setContentsLabel(f'<b>Удаляю: {Attr_type.objects.get(id=id)}, вхождений: {cnt}</b>')
-                            for attribute in Document_attributes.objects.filter(attr_type_id=id):
-                                qty, _ = Document_attr_cross.objects.select_related('attribute').filter(attribute=attribute).delete()
-                                res += qty
+                    with transaction.atomic():
+                        progress.setContentsLabel(f'<b>Удаляю: {Attr_type.objects.get(id=id)}, вхождений: {cnt}</b>')
+                        for attribute in Document_attributes.objects.filter(attr_type_id=id):
+                            qty, _ = Document_attr_cross.objects.select_related('attribute').filter(attribute=attribute).delete()
+                            res += qty
 
-                                qty, _ = Lotsman_document_attr_cross.objects.select_related('attribute').filter(attribute=attribute).delete()
-                                res += qty
+                            qty, _ = Lotsman_document_attr_cross.objects.select_related('attribute').filter(attribute=attribute).delete()
+                            res += qty
 
-                                attribute.delete()
-                                step_res = progress.step()
+                            attribute.delete()
 
-                                if step_res != 0:
-                                    raise ProgressDroped(progress_deleted)
+                            if progress.step() != 0:
+                                raise ProgressDroped(progress_deleted)
+
+                        qty, _ = super().filter(id=id).delete()
 
-                            qty, _ = super().filter(id=id).delete()
-                    except ProgressDroped as ex:
-                        Deleted_progresses.objects.filter(id_progress=progress.id, user=progress.user).delete()
-                        raise ex
             res += qty
         return res
 
@@ -81,7 +75,8 @@ class AttrManager(BaseRefManager):
     @staticmethod
     def get_or_create_attr(attr_codes, attr_names=None, logger=None):
         from django.conf import settings
-        settings.LOCKS.acquire('AttrManager.get_or_create_attr')
+        key = 'AttrManager.get_or_create_attr'
+        settings.LOCKS.acquire(key)
 
         attr_codes = attr_codes.split('.')
         attr_names = attr_names.split('.') if attr_names != None else []
@@ -109,10 +104,10 @@ class AttrManager(BaseRefManager):
             parent_attr_type = attr_type
 
         if attr_type == None:
-            settings.LOCKS.release('AttrManager.get_or_create_attr')
+            settings.LOCKS.release(key)
             raise Exception(f'Failed to create type with code {attr_codes}.')
 
-        settings.LOCKS.release('AttrManager.get_or_create_attr')
+        settings.LOCKS.release(key)
         return attr_type
 
     def get_attr(self, code, name=None, default=None):
