@@ -13,7 +13,6 @@ from kaf_pas.production.models.launch_item_line import Launch_item_line
 from kaf_pas.production.models.launch_item_refs import Launch_item_refs
 from kaf_pas.production.models.launch_operations_item import Launch_operations_item
 from kaf_pas.production.models.operations_item import Operations_item
-from kaf_pas.production.models.ready_2_launch_detail import Ready_2_launch_detail
 from kaf_pas.sales.models.precent_items import Precent_items
 
 logger = logging.getLogger(__name__)
@@ -22,6 +21,11 @@ logger = logging.getLogger(__name__)
 class CombineItems(DSRequest):
     @staticmethod
     def combine(recordTarget, recordsSource):
+        from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
+        from kaf_pas.ckk.models.item_document import Item_document
+
+        Tmp_Item_refsManager.create()
+
         def exec(loger_func=lambda x: bool):
             with transaction.atomic():
                 try:
@@ -103,7 +107,10 @@ class CombineItems(DSRequest):
                 #     if not exec(ready_2_launch_detail.save):
                 #         ready_2_launch_detail.delete()
 
-                Item.objects.filter(id=recordSource.get('id')).delete()
+                res = Item_document.objects.filter(item_id=recordSource.get('id')).delete()
+                logger.debug(f'deleted Item_document ({res})')
+                res = Item.objects.filter(id=recordSource.get('id')).delete()
+                logger.debug(f'deleted Item ({res})')
 
     def __init__(self, request):
         DSRequest.__init__(self, request)
