@@ -7,7 +7,8 @@ from django.db import transaction, connection
 from django.db.models import PositiveIntegerField, BigIntegerField, UniqueConstraint, Q
 from django.forms import model_to_dict
 
-from isc_common import setAttr, delAttr, get_list_nums_key_dict
+from isc_common import setAttr, delAttr, get_list_nums_key_dict, delAttr1
+from isc_common.auth.models.user import User
 from isc_common.bit import TurnBitOn
 from isc_common.common.functions import delete_dbl_spaces
 from isc_common.common.mat_views import refresh_mat_view
@@ -27,8 +28,26 @@ logger = logging.getLogger(__name__)
 
 class ItemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    def create(self, **kwargs):
+        from kaf_pas.ckk.models.item_history import Item_history
+
+        res = super().create(**kwargs)
+
+        item = delAttr1(kwargs, 'id')
+        setAttr(item, 'operation', res)
+        setAttr(item, 'hcreator', res.creator)
+        Item_history.objects.create(**item)
+        return res
+
+    def update(self, **kwargs):
+        from kaf_pas.ckk.models.item_history import Item_history
+
+        res = super().update(**kwargs)
+        item = delAttr1(kwargs, 'id')
+        setAttr(item, 'operation', res)
+        setAttr(item, 'hcreator', res.creator)
+        Item_history.objects.create(**item)
+        return res
 
 
 class ItemManager(CommonManagetWithLookUpFieldsManager):
@@ -116,12 +135,11 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
             return qty > 0
 
     @staticmethod
-    def delete_recursive(item_id, delete_lines=False, soft_delete=False, user=None, props=TurnBitOn(0, 0), document=None, show_progress=True):
+    def delete_recursive(item_id, delete_lines=False, soft_delete=None, user=None, props=TurnBitOn(0, 0), document=None, show_progress=True):
         from kaf_pas.ckk.models.item_document import Item_document
         from kaf_pas.ckk.models.item_image_refs import Item_image_refs
         from kaf_pas.ckk.models.item_line import Item_line
         from kaf_pas.ckk.models.item_refs import Item_refs
-        from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
         from kaf_pas.production.models.operations_item import Operations_item
 
         key = 'ItemManager.delete_recursive'
@@ -191,7 +209,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                             for item in Item_refs.objects.get_descendants(id=item_id, order_by_clause='order by level desc', sql_text=sql_text):
                                 _item = item
                                 _continue = False
-                                if not soft_delete:
+                                if soft_delete == None:
                                     if document != None:
                                         if ItemManager.check_4_production(item=item.child_id) == True:
                                             _continue = True
@@ -215,18 +233,12 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                                     Item_document.objects.filter(item_id=item.child_id).delete()
                                     Item.objects.filter(id=item.child_id).delete()
                                 else:
-                                    # Item_image_refs.objects.filter(item_id=item.child_id).soft_delete()
-                                    #
-                                    # if delete_lines:
-                                    #     Item_line.objects.filter(parent_id=item.child_id).soft_delete()
-                                    #     Item_line.objects.filter(child_id=item.child_id).soft_delete()
-                                    #
-                                    #     Item_line.objects.filter(parent_id=item.parent_id).soft_delete()
-                                    #     Item_line.objects.filter(child_id=item.parent_id).soft_delete()
-                                    #
-                                    # Item_refs.objects.filter(parent_id=item.child_id).soft_delete()
-                                    # Item_refs.objects.filter(child_id=item.child_id).soft_delete()
-                                    Item.objects.filter(id=item.child_id).soft_delete()
+                                    if soft_delete == 'hide':
+                                        Item.objects.filter(id=item.child_id).soft_delete()
+                                    elif soft_delete == 'visible':
+                                        Item.objects.filter(id=item.child_id).soft_restore()
+                                    else:
+                                        raise Exception(f'soft_delete : {soft_delete} this unknown mode')
 
                                 if progress != None:
                                     if progress.step() != 0:
@@ -453,10 +465,10 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                     return res
 
         for id, mode in request.get_tuple_ids():
-            if mode == 'hide':
-                res = self.delete_recursive(item_id=id, soft_delete=True, delete_lines=True, user=request.user_id)
+            if mode in ['hide', 'visible']:
+                res = self.delete_recursive(item_id=id, soft_delete=mode, delete_lines=True, user=request.user_id)
             else:
-                res = self.delete_recursive(item_id=id, soft_delete=False, delete_lines=True, user=request.user_id)
+                res = self.delete_recursive(item_id=id, delete_lines=True, user=request.user_id)
         return res
 
     def lookupFromRequest(self, request):
@@ -638,6 +650,7 @@ class Item(AuditModel):
     document = ForeignKeyProtect(Documents, verbose_name='Документ', null=True, blank=True)
     lotsman_document = ForeignKeyProtect(Lotsman_documents_hierarcy, verbose_name='Документ из Лоцмана', null=True, blank=True)
     lotsman_type_id = BigIntegerField(null=True, blank=True)
+    creator = ForeignKeyProtect(User)
 
     objects = ItemManager()
 
