@@ -442,23 +442,22 @@ class Item_line(AuditModel):
         return self.SPC_CLM_COUNT.value_int
 
     def __str__(self):
-        return f'\n\nchild=[{self.child}]\n' \
-               f'\nparent=[{self.parent}]\n' \
-               f'\nSPC_CLM_FORMAT=[{self.SPC_CLM_FORMAT}]' \
-               f'\nSPC_CLM_ZONE=[{self.SPC_CLM_ZONE}]' \
-               f'\nSPC_CLM_POS=[{self.SPC_CLM_POS}]' \
-               f'\nSPC_CLM_MARK=[{self.SPC_CLM_MARK}]' \
-               f'\nSPC_CLM_NAME=[{self.SPC_CLM_NAME}]' \
-               f'\nSPC_CLM_COUNT=[{self.SPC_CLM_COUNT}]' \
-               f'\nSPC_CLM_NOTE=[{self.SPC_CLM_NOTE}]' \
-               f'\nSPC_CLM_MASSA=[{self.SPC_CLM_MASSA}]' \
-               f'\nSPC_CLM_MATERIAL=[{self.SPC_CLM_MATERIAL}]' \
-               f'\nSPC_CLM_USER=[{self.SPC_CLM_USER}]' \
-               f'\nSPC_CLM_KOD=[{self.SPC_CLM_KOD}' \
-               f'\nSPC_CLM_FACTORY=[{self.SPC_CLM_FACTORY}]\n' \
-               f'\nEdIzm=[{self.edizm}]\n' \
-               f'section={self.section}\n' \
-               f'subsection={self.subsection}\n\n'
+        return f'\nparent: [{self.parent}]\n' \
+               f'\nSPC_CLM_FORMAT: [{self.SPC_CLM_FORMAT}]' \
+               f'\nSPC_CLM_ZONE: [{self.SPC_CLM_ZONE}]' \
+               f'\nSPC_CLM_POS: [{self.SPC_CLM_POS}]' \
+               f'\nSPC_CLM_MARK: [{self.SPC_CLM_MARK}]' \
+               f'\nSPC_CLM_NAME: [{self.SPC_CLM_NAME}]' \
+               f'\nSPC_CLM_COUNT: [{self.SPC_CLM_COUNT}]' \
+               f'\nSPC_CLM_NOTE: [{self.SPC_CLM_NOTE}]' \
+               f'\nSPC_CLM_MASSA: [{self.SPC_CLM_MASSA}]' \
+               f'\nSPC_CLM_MATERIAL: [{self.SPC_CLM_MATERIAL}]' \
+               f'\nSPC_CLM_USER: [{self.SPC_CLM_USER}]' \
+               f'\nSPC_CLM_KOD: [{self.SPC_CLM_KOD}' \
+               f'\nSPC_CLM_FACTORY: [{self.SPC_CLM_FACTORY}]\n' \
+               f'\nEdIzm: [{self.edizm}]\n' \
+               f'section: {self.section}\n' \
+               f'subsection: {self.subsection}\n\n'
 
     def __repr__(self):
         return self.__str__()
