@@ -5,10 +5,12 @@ from kaf_pas.ckk.views import item_view
 urlpatterns = [
 
     path('ItemView/Fetch/', item_view.Item_view_Fetch),
+    path('ItemView_4_id/Fetch/', item_view.Item_view_4_idFetch),
     path('ItemView/Fetch1/', item_view.Item_view_Fetch1),
     path('ItemView/Fetch2/', item_view.Item_view_Fetch2),
     path('ItemView/Fetch3/', item_view.Item_view_Fetch3),
     path('ItemView/Fetch4/', item_view.Item_view_Fetch4),
+    path('ItemView/Fetch5/', item_view.Item_view_Fetch5),
     path('ItemView/Add', item_view.Item_view_Add),
     path('ItemView/Update', item_view.Item_view_Update),
     path('ItemView/Update1', item_view.Item_view_Update1),
