@@ -10,7 +10,12 @@ def Item_Fetch(request):
         DSResponse(
             request=request,
             data=Item.objects.
-                filter().
+                select_related(
+                'STMP_1',
+                'STMP_2',
+                'document',
+                'lotsman_document',
+            ).
                 get_range_rows1(
                 request=request,
                 function=ItemManager.getRecord
@@ -45,10 +50,9 @@ def Item_Info(request):
 
 @JsonResponseWithException()
 def Item_CheckRecursives(request):
-    return JsonResponse(DSResponse(request=request, data=Item.objects.checkRecursives(request=request), status=RPCResponseConstant.statusSuccess).response)\
+    return JsonResponse(DSResponse(request=request, data=Item.objects.checkRecursives(request=request), status=RPCResponseConstant.statusSuccess).response)
+
 
 @JsonResponseWithException()
 def GetQtyChilds(request):
     return JsonResponse(DSResponse(request=request, data=Item.objects.getQtyChilds(request=request), status=RPCResponseConstant.statusSuccess).response)
-
-
