@@ -114,7 +114,9 @@ class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
     @staticmethod
     def get_or_create_attribute(attr_codes, value_str, attr_names=None, logger=None):
         from django.conf import settings
-        settings.LOCKS.acquire('Document_attributesManager.get_or_create_attribute')
+
+        key = 'Document_attributesManager.get_or_create_attribute'
+        settings.LOCKS.acquire(key)
         attr_type = AttrManager.get_or_create_attr(attr_codes=attr_codes, attr_names=attr_names, logger=logger)
         value_int = StrToNumber(value_str)
 
@@ -123,7 +125,7 @@ class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
                 value_str__delete_dbl_spaces=delete_dbl_spaces(value_str),
                 attr_type=attr_type,
             ).order_by('id')[0]
-            settings.LOCKS.release('Document_attributesManager.get_or_create_attribute')
+            settings.LOCKS.release(key)
             return attribute, False
         except IndexError:
             attribute = Document_attributes.objects.create(
@@ -131,7 +133,7 @@ class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
                 value_str=delete_dbl_spaces(value_str),
                 value_int=value_int
             )
-            settings.LOCKS.release('Document_attributesManager.get_or_create_attribute')
+            settings.LOCKS.release(key)
             return attribute, True
 
     def get_queryset(self):
@@ -231,7 +233,7 @@ class Document_attributes(AuditModel):
     objects = Document_attributesManager()
 
     def __str__(self):
-        return f'ID={self.id}, attr_type=[{self.attr_type}], value_str={self.value_str.strip()}, value_int={self.value_int}'
+        return f'ID={self.id}, attr_type=[{self.attr_type}], value_str={self.value_str}, value_int={self.value_int}'
 
     class Meta:
         verbose_name = 'Аттрибуты докуменнта'
