@@ -233,7 +233,8 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
         if not isinstance(user, User):
             raise Exception(f'user  must be a User instance.')
 
-        settings.LOCKS.acquire('DocumentManager.delete')
+        key='DocumentManager.delete'
+        settings.LOCKS.acquire(key)
         res = 0
         lotsman_res = 0
 
@@ -264,7 +265,7 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
         Documents_thumb10.objects.filter(lotsman_document__document_id=id).delete()
 
         res += Documents.objects.filter(id=id).delete()[0]
-        settings.LOCKS.release('DocumentManager.delete')
+        settings.LOCKS.release(key)
         return res, lotsman_res
 
     def deleteFromRequest(self, request):
