@@ -12,7 +12,7 @@ def download_attach_file(request, id):
     ws_port = settings.WS_PORT
     ws_host = settings.WS_HOST
 
-    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/DocumentsThumb/Download/{id}/', params=dict(ws_port=ws_port, ws_channel=ws_channel, ws_host=ws_host))
+    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/DocumentsThumb/Download/{id}/', params=dict(ws_port=ws_port, ws_channel=ws_channel, ws_host=ws_host, user_id=request.user_id))
     logger.debug(f'DocumentsThumb url: {r.url}')
     return HttpResponseRedirect(r.url)
 
@@ -22,6 +22,6 @@ def download_attach_file_10(request, id):
     ws_port = settings.WS_PORT
     ws_host = settings.WS_HOST
 
-    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/DocumentsThumb/Download10/{id}/', params=dict(ws_port=ws_port, ws_channel=ws_channel, ws_host=ws_host))
+    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/DocumentsThumb/Download10/{id}/', params=dict(ws_port=ws_port, ws_channel=ws_channel, ws_host=ws_host, user_id=request.user_id))
     logger.debug(f'DocumentsThumb10 url: {r.url}')
     return HttpResponseRedirect(r.url)
