@@ -22,7 +22,8 @@ class Spw_attrsQuerySet(Document_attributesQuerySet):
 
     @staticmethod
     def make_specification(queryResult):
-        settings.LOCKS.acquire('Spw_attrsQuerySet.make_specification')
+        key='Spw_attrsQuerySet.make_specification'
+        settings.LOCKS.acquire(key)
         res = []
         attr_typee_id = sys.maxsize
         id = None
@@ -59,7 +60,7 @@ class Spw_attrsQuerySet(Document_attributesQuerySet):
 
         # for item in res:
         #     logger.debug(item)
-        settings.LOCKS.release('Spw_attrsQuerySet.make_specification')
+        settings.LOCKS.release(key)
         return res
 
     def get_range_rows1(self, request, function=None):
@@ -78,7 +79,8 @@ class Spw_attrsManager(Document_attributes_viewManager):
         from kaf_pas.kd.models.document_attr_cross import Document_attr_cross
         from kaf_pas.kd.models.documents import Documents
 
-        settings.LOCKS.acquire('Spw_attrsManager.rec_document_attr')
+        key='Spw_attrsManager.rec_document_attr'
+        settings.LOCKS.acquire(key)
         if attr_type_id == None:
             if code != None and attr_type__code != None:
                 attr_type, _ = Document_attributesManager.get_or_create_attribute(attr_codes=code, value_str=attr_type__code)
@@ -122,13 +124,14 @@ class Spw_attrsManager(Document_attributes_viewManager):
                 section=section,
                 subsection=subsection,
             )
-            settings.LOCKS.release('Spw_attrsManager.rec_document_attr')
+            settings.LOCKS.release(key)
             return res
-        settings.LOCKS.release('Spw_attrsManager.rec_document_attr')
+        settings.LOCKS.release(key)
 
     @staticmethod
     def update_rec_spesification(data):
-        settings.LOCKS.acquire(f'''Spw_attrsManager.update_rec_spesification_{data.get('document_id')}''')
+        key=f'''Spw_attrsManager.update_rec_spesification_{data.get('document_id')}'''
+        settings.LOCKS.acquire(key)
         with transaction.atomic():
             attr_type__code = 'SPC_CLM_FORMAT'
             Spw_attrsManager.rec_document_attr(
@@ -273,7 +276,7 @@ class Spw_attrsManager(Document_attributes_viewManager):
                 section=data.get('section'),
                 subsection=data.get('subsection'),
             )
-        settings.LOCKS.release(f'''Spw_attrsManager.update_rec_spesification_{data.get('document_id')}''')
+        settings.LOCKS.release(key)
 
     def updateFromRequest(self, request, removed=None, function=None):
         request = DSRequest(request=request)
