@@ -59,7 +59,7 @@ def Documents_view_Remove(request):
 
     _request = DSRequest(request=request)
     ids = _request.get_tuple_ids()
-    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/Documents/Remove', params=dict(ids=ids, port=ws_port, ws_channel=ws_channel, host=host))
+    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/Documents/Remove', params=dict(ids=ids, port=ws_port, ws_channel=ws_channel, host=host, user_id=_request.user_id))
     HttpResponseRedirect(r.url)
     return JsonResponse(DSResponse(request=request, status=RPCResponseConstant.statusSuccess).response)
 
