@@ -2,7 +2,7 @@ import logging
 
 from django.core.management import BaseCommand
 
-from kaf_pas.planing.models.routing import RoutingManager
+from kaf_pas.planing.models.rouning_ext import Route_item
 
 logger = logging.getLogger(__name__)
 
@@ -10,5 +10,6 @@ logger = logging.getLogger(__name__)
 class Command(BaseCommand):
     def handle(self, *args, **options):
         # print(RoutingManager.make_levels(launch_id=30))
-        for item in RoutingManager.make_locationsLevel(launch_id=23, level_id=17):
+        route_item = Route_item()
+        for item in route_item.make_locationsLevel(launch_id=23, level_id=17):
             print(item)
