@@ -30,7 +30,7 @@ class LevelsManager(BaseRefManager):
 
 
 class Levels(BaseRef):
-    code = PositiveIntegerField()
+    code = PositiveIntegerField(db_index=True, unique=True)
     objects = LevelsManager()
 
     def __str__(self):
