@@ -12,7 +12,6 @@ from isc_common.number import DecimalToStr
 from kaf_pas.ckk.models.ed_izm import Ed_izm
 from kaf_pas.ckk.models.item import Item
 from kaf_pas.ckk.models.locations import Locations
-from kaf_pas.planing.models.levels import Levels
 from kaf_pas.planing.models.operation_operation import Operation_operation
 from kaf_pas.planing.models.operation_refs import Operation_refsManager
 from kaf_pas.planing.models.operation_types import Operation_types
@@ -55,7 +54,7 @@ class Operations_viewManager(TreeAuditModelManager):
             'operation_operation_edizm_id': record.operation_operationn.ed_izm.id if record.operation_operation and record.operation_operation.ed_izm else None,
             'operation_operation_id': record.operation_operation.id if record.operation_operation else None,
             'operation_operation_num': record.operation_operation.num if record.operation_operation else None,
-            'operation_operation_qty':  DecimalToStr(record.operation_operation.qty) if record.operation_operation else None,
+            'operation_operation_qty': DecimalToStr(record.operation_operation.qty) if record.operation_operation else None,
             'opertype__full_name': record.opertype.full_name,
             'opertype_id': record.opertype.id,
             'parent_id': record.parent.id if record.parent else None,
@@ -88,6 +87,7 @@ class Operations_view(Hierarcy):
     edizm = ForeignKeySetNull(Ed_izm, null=True, blank=True)
     isFolder = BooleanField(default=None)
     item = ForeignKeySetNull(Item, null=True, blank=True)
+    launch = ForeignKeySetNull(Launches, null=True, blank=True)
     location = ForeignKeySetNull(Locations, null=True, blank=True)
     mark = CodeField()
     num = CodeField()
@@ -95,7 +95,6 @@ class Operations_view(Hierarcy):
     opertype = ForeignKeyProtect(Operation_types, related_name='Operations_view_opertype')
     production_operation = ForeignKeySetNull(Operations, null=True, blank=True)
     props = Operation_refsManager.props()
-    launch = ForeignKeySetNull(Launches, null=True, blank=True)
     resource = ForeignKeySetNull(Resource, null=True, blank=True)
     status = ForeignKeyProtect(Status_operation_types)
     value = DecimalField(decimal_places=4, max_digits=19, null=True, blank=True)
@@ -103,13 +102,26 @@ class Operations_view(Hierarcy):
     objects = Operations_viewManager()
 
     def __str__(self):
-        # return f"ID:{self.id}, \n" \
-        #        f"num:{self.num}, \n" \
-        #        f"creator: [{self.creator}], \n" \
-        #        f"date: {self.date}, \n" \
-        #        f"description: {self.description}, \n" \
-        #        f"parent_id: {self.parent}, \n"
-        return super().__str__()
+        try:
+            return f"ID:{self.id}, \n" \
+                   f"num:{self.num}, \n" \
+                   f"creator: [{self.creator}], \n" \
+                   f"date: {self.date}, \n" \
+                   f"edizm: [{self.edizm}], \n" \
+                   f"item: [{self.item}], \n" \
+                   f"location: [{self.location}], \n" \
+                   f"opertype: [{self.opertype}, \n" \
+                   f"production_operation: [{self.production_operation}], \n" \
+                   f"props: {self.props}, \n" \
+                   f"launch: [{self.launch}], \n" \
+                   f"resource: [{self.resource}], \n" \
+                   f"status: [{self.status}], \n" \
+                   f"value: {self.value}, \n" \
+                   f"description: {self.description}, \n" \
+                   f"parent_id: {self.parent}, \n"
+        except Exception as ex:
+            return str(ex)
+        # return super().__str__()
 
     def __repr__(self):
         return self.__str__()
