@@ -196,6 +196,8 @@ class WrapperProductionOrder(Wrapper):
     production_operation_id = None
     production_operation_num = None
     production_operation_qty = None
+    value_sum = None
+    value1_sum = None
     qty = None
     resource_id = None
 
@@ -940,6 +942,7 @@ class Production_ext:
 
     def _create_tech_specification(self, data, user):
         from django.conf import settings
+        from kaf_pas.ckk.models.locations import Locations
         from kaf_pas.planing.models.operation_operation import Operation_operation
         from kaf_pas.production.models.operation_def_material import Operation_def_material
         from kaf_pas.production.models.operation_material import Operation_material
@@ -965,7 +968,7 @@ class Production_ext:
             batch_size=1
         )
         operations_item.resource = Resource.objects.get(id=data.resource_id) if data.resource_id else None
-        operations_item.location_fin_id = data.location_fin_id
+        operations_item.location_fin = Locations.objects.get(id=data.location_fin_id) if data.location_fin_id != None else None
 
         for operation_def_material in Operation_def_material.objects.filter(operation_id=data.production_operation_id):
             Operation_material.objects.create(
@@ -978,7 +981,7 @@ class Production_ext:
 
         operations_item.operation_materials = Stack([operation_material for operation_material in Operation_material.objects.filter(operationitem=operations_item)])
 
-        return self.rec_operation(
+        operation = self.rec_operation(
             launch=data.parentRecord.get('launch_id'),
             status=settings.OPERS_TYPES_STACK.PRODUCTION_DETAIL_OPERS_TASK_STATUSES.get('new'),
             operations_item=operations_item,
@@ -989,6 +992,8 @@ class Production_ext:
             props=Operation_operation.props.direct_created
         )
 
+        return operation
+
     def _update_tech_specification(self, data, old_data, tmp_table_name):
         from isc_common.number import StrToNumber
         from kaf_pas.ckk.models.item_line import Item_line
@@ -1025,11 +1030,21 @@ class Production_ext:
 
         operations_item = operations_query[0]
         # Нумерация в составе списка операций
-        if data.production_operation_num != old_data.production_operation_num:
-            aa = [a for a in Operations_item.objects.filter(item=parent_operation.item).order_by('num', '-lastmodified') if a.num == old_data.production_operation_num]
+        if old_data == None or data.production_operation_num != old_data.production_operation_num:
+            num = old_data.production_operation_num if old_data != None else data.production_operation_num
+
+            aa_created = [a for a in Operations_item.objects.filter(item=parent_operation.item, props=Operations_item.props.created).order_by('num') if a.num == num]
+            if len(aa_created) == 0:
+                aa = [a for a in Operations_item.objects.filter(item=parent_operation.item).order_by('num') if a.num == num]
+            else:
+                aa = aa_created
+
             if len(aa) > 0:
                 aa = aa[0]
-                bb = [a for a in Operations_item.objects.filter(item=parent_operation.item).order_by('num', '-lastmodified') if a.num != old_data.production_operation_num]
+                if len(aa_created) == 0:
+                    bb = [a for a in Operations_item.objects.filter(item=parent_operation.item).order_by('num') if a.num != num]
+                else:
+                    bb = [a for a in Operations_item.objects.filter(item=parent_operation.item).exclude(props=Operations_item.props.created).order_by('num')]
                 bb.insert(data.production_operation_num - 1, aa)
                 num = 1
                 for _bb in bb:
@@ -1042,17 +1057,17 @@ class Production_ext:
                 operations_item = bb[data.production_operation_num - 1]
 
             # Длительность операции
-            if data.production_operation_qty != old_data.production_operation_qty:
+            if (old_data == None and data.production_operation_qty != None) or (data.production_operation_qty != old_data.production_operation_qty):
                 operations_item.qty = data.production_operation_qty
                 edited = True
 
             # Еденица измерения длительности операции
-            if data.production_operation_edizm_id != old_data.production_operation_edizm_id:
+            if (old_data == None and data.production_operation_edizm_id != None) or (data.production_operation_edizm_id != old_data.production_operation_edizm_id):
                 operations_item.edizm_id = data.production_operation_edizm_id
                 edited = True
 
             # Кол-во на еденицу продукции
-            if data.value1_sum != old_data.value1_sum:
+            if (old_data == None and data.value1_sum != None) or (old_data != None and old_data.value1_sum != data.value1_sum):
                 for item_operations in Item_operations_view.objects.raw(raw_query=f'select * from {tmp_table_name} where id = %s', params=[parent_operation.item.id]):
                     item_refs = Item_refs.objects.get(id=item_operations.refs_id)
                     for item_line in Item_line.objects.filter(parent=item_refs.parent, child=item_refs.child):
@@ -1062,7 +1077,7 @@ class Production_ext:
                         edited = True
 
             # Ед. изм. Кол-ва на еденицу продукции
-            if data.edizm_id != old_data.edizm_id:
+            if (old_data == None and data.edizm_id != None) or (old_data != None and old_data.edizm_id != data.edizm_id):
                 for item_operations in Item_operations_view.objects.raw(raw_query=f'select * from {tmp_table_name} where id = %s', params=[parent_operation.item.id]):
                     item_refs = Item_refs.objects.get(id=item_operations.refs_id)
                     for item_line in Item_line.objects.filter(parent=item_refs.parent, child=item_refs.child):
@@ -1076,17 +1091,17 @@ class Production_ext:
             edited_resource = False
             for operation_resources in Operation_resources.objects.filter(operationitem=operations_item):
                 # Ресурс на котором выполняется данная операция
-                if data.resource_id != old_data.resource_id:
+                if (old_data == None and data.resource_id != None) or (old_data != None and data.resource_id != old_data.resource_id):
                     operation_resources.resource_id = data.resource_id
                     edited_resource = True
 
                 # Место выполнения данная операции
-                if data.location_id != old_data.location_id:
+                if (old_data == None and data.location_id != None) or (old_data != None and old_data.location_id != data.location_id):
                     operation_resources.location_id = data.location_id
                     edited_resource = True
 
                 # Место окончания выполнения данной операции
-                if data.location_fin_id != old_data.location_fin_id:
+                if (old_data == None and data.location_fin_id != None) or (old_data != None and data.location_fin_id != old_data.location_fin_id):
                     operation_resources.location_fin_id = data.location_fin_id
                     edited_resource = True
 
@@ -1096,7 +1111,7 @@ class Production_ext:
                 if not edited:
                     edited = edited_resource
 
-            if data.description != old_data.description:
+            if (old_data == None and data.description != None) or (data.description != old_data.description):
                 operation.description = data.description
                 operation.save()
 
@@ -1186,6 +1201,7 @@ class Production_ext:
                     filter(deleted_at__isnull=True). \
                     soft_delete()
 
+        logger.debug(f' launch_operations_items.size: { launch_operations_items.size()}')
         return launch_operations_items
 
     def _update_routing(self, data, old_data, user: User, updated_launch_operations_items: Stack):
@@ -1234,7 +1250,6 @@ class Production_ext:
             if old_data == None:
                 data.parent_id = data.parentRecord.get('id')
                 data.id = self._create_tech_specification(data=data, user=user)
-                old_data = data
 
             tmp_table_name = self.get_production_order_tmp_table(id=data.parent_id)
 
