@@ -10,7 +10,7 @@ from django.forms import model_to_dict
 from isc_common import Stack, Wrapper, setAttr
 from isc_common.auth.models.user import User
 from isc_common.bit import TurnBitOn
-from isc_common.common import new
+from isc_common.common import new, doing, restarted
 from isc_common.common.functions import ExecuteStoredProc
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
@@ -33,7 +33,27 @@ class Production_orderWrapper(Wrapper):
 
 
 class Production_order_valuesQuerySet(OperationsQuerySet):
-    pass
+    def get_range_rows1(self, request, function=None, distinct_field_names=None, remove_fields=None):
+        request = DSRequest(request=request)
+
+        parent_id = request.get_data().get('parent_id')
+        if parent_id == None:
+            request.set_data(dict(parent_id=0))
+
+        self.alive_only = request.alive_only
+        self.enabledAll = request.enabledAll
+        res = self.get_range_rows(
+            start=request.startRow,
+            end=request.endRow,
+            function=function,
+            distinct_field_names=distinct_field_names,
+            json=request.json,
+            criteria=request.get_criteria(),
+            user=request.user
+        )
+        # import time
+        # time.sleep(1)
+        return res
 
 
 class Production_order_valuesManager(OperationsManager):
@@ -73,11 +93,12 @@ class Production_order_valuesManager(OperationsManager):
 
     @staticmethod
     def blockMakeAll(data, user):
-        from kaf_pas.planing.models.production_order import Production_orderQuerySet
         from kaf_pas.planing.models.production_order import Production_order
         from kaf_pas.planing.models.production_order_opers import Production_order_opers
+        from kaf_pas.planing.models.production_ext import Production_ext
 
         _res = []
+        production_ext = Production_ext()
         records = data.get('records')
         if isinstance(records, list):
             with managed_progress(
@@ -107,7 +128,7 @@ class Production_order_valuesManager(OperationsManager):
                         qty = operation.value_sum
 
                         if operation.status.id == settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(new).id and operation.cnt_opers == 1:
-                            Production_orderQuerySet.start(
+                            production_ext.start(
                                 _data=_data,
                                 qty=qty,
                                 user=user,
@@ -128,21 +149,42 @@ class Production_order_valuesManager(OperationsManager):
                         if progress.step() != 0:
                             settings.LOCKS.release(key)
                             raise ProgressDroped(progress_deleted)
+
+                        WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_grid_row, records=[model_to_dict(operation)])
             settings.LOCKS.release(key)
             return _res
         else:
             raise Exception('Не сделан выбор.')
 
+    @staticmethod
+    def check_enoph_components(enableMinus, value, warnings, parent):
+        from kaf_pas.production.models.launch_item_prod_order_view import Launch_item_order_view
+        from kaf_pas.planing.models.operation_item import Operation_item
+
+        warnings.clear()
+        qty_need = 0
+        for launch_item_order_view in Launch_item_order_view.objects.filter(parent=Operation_item.objects.get(operation_id=parent.id).item).exclude(section='Документация'):
+            qty_need = launch_item_order_view.qty_per_one * value
+            if qty_need > launch_item_order_view.qty_exists:
+                message = f'Недостаточно комплектации по: {launch_item_order_view.item.item_name}, в наличии {DecimalToStr(launch_item_order_view.qty_exists)} а необходимо {DecimalToStr(qty_need)}'
+                if enableMinus == True:
+                    warnings.push(message)
+                else:
+                    WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_operationsValues_grid)
+                    raise Exception(message)
+        return qty_need, warnings
+
     @staticmethod
     def makeAll(data, user, lock=True):
         from kaf_pas.planing.models.operation_color import Operation_color
         from kaf_pas.planing.models.operation_item import Operation_item
         from kaf_pas.planing.models.operation_launches import Operation_launches
         from kaf_pas.planing.models.operation_refs import Operation_refs
+        from kaf_pas.planing.models.operation_resources import Operation_resources
         from kaf_pas.planing.models.production_order import Production_order
+        from kaf_pas.planing.models.production_order import Production_orderManager
         from kaf_pas.planing.models.production_order_opers import Production_order_opers
         from kaf_pas.planing.models.production_order_per_launch import Production_order_per_launch
-        from kaf_pas.planing.models.operation_resources import Operation_resources
 
         def rec_item_releases(parent, value, edizm_id, launch_id, warnings, enableMinus, maked_operations, resource_id, location_fin_id=None):
             # Записываем расход комплектующик
@@ -152,10 +194,10 @@ class Production_order_valuesManager(OperationsManager):
                 qty_need = launch_item_order_view.qty_per_one * value
                 if qty_need > launch_item_order_view.qty_exists:
                     message = f'Недостаточно комплектации по: {launch_item_order_view.item.item_name}, в наличии {DecimalToStr(launch_item_order_view.qty_exists)} а необходимо {DecimalToStr(qty_need)}'
-                    if enableMinus == True:
-                        warnings.push(message)
-                    else:
-                        raise Exception(message)
+                    # if enableMinus == True:
+                    #     warnings.push(message)
+                    # else:
+                    #     raise Exception(message)
 
                 release_item_operation = Operations.objects.create(
                     date=datetime.now(),
@@ -260,6 +302,7 @@ class Production_order_valuesManager(OperationsManager):
                 logger.debug(f'Created operation_color :  {operation_color}')
             else:
                 if previos_color_id != None:
+                    WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_operationsValues_grid)
                     raise Exception(f'Не указан цвет, который приcутствует в предыдущей операции.')
 
             if parent != None:
@@ -271,8 +314,12 @@ class Production_order_valuesManager(OperationsManager):
                 logger.debug(f'Created operation_refs :  {operation_refs}')
 
             # todo проверяем на полность выполненность
-            parent_po = Production_order.objects.get(id=parent.id)
-            if parent_po.value_odd == 0:
+            value_odd = Production_order_per_launch.objects.filter(id=parent.id).values('value_odd').distinct()
+            value_odd = value_odd[0].get('value_odd')
+            if value_odd == None:
+                value_odd = 0
+
+            if value_odd == 0:
                 parent.status = settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get('doing')
                 parent.save()
 
@@ -284,6 +331,12 @@ class Production_order_valuesManager(OperationsManager):
                 )
                 logger.debug(f'Created operation_refs :  {operation_refs}')
 
+            records = [Production_orderManager.getRecord(record) for record in Production_order.objects.filter(id=parent.id)]
+            WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_grid_row, records=records)
+            WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_operationsValues_grid)
+            WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_item_grid)
+            WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_buffers_grid)
+
         def rec_operation_made(value, parent, edizm_id, prev_child, color_id=None):
             launch_release_operation = Operations.objects.create(
                 date=datetime.now(),
@@ -325,6 +378,12 @@ class Production_order_valuesManager(OperationsManager):
                     props=Operation_refs.props.product_making
                 )
                 logger.debug(f'Created operation_refs :  {prev_operation_refs}')
+
+            record = parent.dict
+            setAttr(record, 'value_made', value)
+            WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_operationsGrid_row, records=[record])
+            WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_operationsValues_grid)
+
             return operation_refs
 
         # raise Exception('Функция находится в разработке.')
@@ -378,6 +437,15 @@ class Production_order_valuesManager(OperationsManager):
                         if lock:
                             settings.LOCKS.release(key)
                         raise Exception(f'Не достаточно выпуска в предыдущей операции. Возможное количество {DecimalToStr(value_enabled)}')
+
+                    if color_id != None:
+                        value_on_coors = ExecuteStoredProc('get_operation_colors_qty', [parent.id, color_id, operation.production_operation_num])
+                        if value_on_coors != None and value_on_coors < value:
+                            if lock:
+                                settings.LOCKS.release(key)
+                            WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_operationsValues_grid)
+                            raise Exception(f'Не достаточно изделий данного цвета. Возможное количество {DecimalToStr(value_on_coors)}')
+
                 break
             # ===================================================================================================================================
 
@@ -397,6 +465,7 @@ class Production_order_valuesManager(OperationsManager):
             if min_value_made < value:
                 if lock:
                     settings.LOCKS.release(key)
+                WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_operationsValues_grid)
                 raise Exception(f'Превышение количества. Максимально возможное: {DecimalToStr(min_value_made)}')
             else:
                 min_value_made = value
@@ -404,7 +473,12 @@ class Production_order_valuesManager(OperationsManager):
 
             # ===============================Записываем выполнение выбранных операций =================================================================
             maked_operations = Stack()
+            checked = False
             for operation in operations:
+                if not checked:
+                    _, warnings = Production_order_valuesManager.check_enoph_components(enableMinus=enableMinus, value=min_value_made, warnings=warnings, parent=parent)
+                    checked = True
+
                 previos_operation = rec_operation_made(
                     parent=operation,
                     color_id=color_id,
@@ -413,6 +487,18 @@ class Production_order_valuesManager(OperationsManager):
                     value=min_value_made,
                 )
                 maked_operations.push(previos_operation)
+
+            if warnings.size() > 0:
+                if not enableMinus:
+                    raise Exception('\n'.join(warnings.stack))
+                else:
+                    WebSocket.send_warning_message(
+                        host=settings.WS_HOST,
+                        port=settings.WS_PORT,
+                        channel=f'common_{user.username}',
+                        message='<br/><br/>'.join(warnings.stack),
+                        logger=logger
+                    )
             # ===================================================================================================================================
 
             # ==================== Проверяем возможность выпуска релиза ========================================================================
@@ -421,8 +507,12 @@ class Production_order_valuesManager(OperationsManager):
             min_value_made = Production_order_opers.objects.filter(parent_id=parent.id).aggregate(Min('value_made')).get('value_made__min')
 
             value_made = Production_order.objects.filter(id=parent.id).values('value_made').distinct()
-            if value_made.count() > 0:
-                min_value_made -= value_made[0]
+            value_made = value_made[0].get('value_made')
+            if value_made == None:
+                value_made = 0
+
+            if value_made > 0:
+                min_value_made -= value_made
 
             if min_value_made > 0:
 
@@ -444,7 +534,10 @@ class Production_order_valuesManager(OperationsManager):
                     for row in rows:
                         id, _, _, _ = row
 
-                        value_odd = Production_order_per_launch.objects.get(id=parent.id, launch_id=id).value_odd
+                        value_odd = Production_order_per_launch.objects.filter(id=parent.id, launch_id=id).values('value_odd').distinct()
+                        value_odd = value_odd[0].get('value_odd')
+                        if value_odd == None:
+                            value_odd = 0
 
                         if value_odd > 0:
                             if min_value_made > value_odd:
@@ -537,6 +630,7 @@ class Production_order_valuesManager(OperationsManager):
         except Exception as ex:
             if lock:
                 settings.LOCKS.release(key)
+                WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_operationsValues_grid)
             raise ex
 
         if lock:
@@ -558,6 +652,7 @@ class Production_order_valuesManager(OperationsManager):
                 release_query = Operation_refs.objects.filter(parent_id=id, child__opertype__code__in=[RELEASE_TSK_PLS, RELEASE_TSK_MNS])
                 if release_query.count() == 0:
                     res, _ = Operation_refs.objects.filter(child_id=id, parent__opertype__code__in=[MADE_OPRS_TSK, DETAIL_OPERS_PRD_TSK]).delete()
+                    res, _ = Operation_refs.objects.filter(parent_id=id, child__opertype__code__in=[MADE_OPRS_TSK, DETAIL_OPERS_PRD_TSK]).delete()
                 else:
                     # Удаляем релизы если они есть
                     for operation_refs in release_query:
@@ -569,12 +664,17 @@ class Production_order_valuesManager(OperationsManager):
                         res, _ = child.delete()
 
                     # Удаляем блок учавствующий в релизе
-                    for operation_refs in Operation_refs.objects.filter(parent_id=id, props=Operation_refs.props.product_making_block, parent__opertype__code=MADE_OPRS_TSK):
+                    for operation_refs in Operation_refs.objects.filter(
+                            parent_id=id,
+                            # props=Operation_refs.props.product_making_block,
+                            parent__opertype__code=MADE_OPRS_TSK):
+
                         op = operation_refs.child
                         logger.debug(op)
                         for otrf in Operation_refs.objects.filter(child=op):
                             logger.debug(otrf)
                             otrf.delete()
+
                         for otrf in Operation_refs.objects.filter(parent=op):
                             logger.debug(otrf)
                             otrf.delete()
@@ -589,8 +689,14 @@ class Production_order_valuesManager(OperationsManager):
                         otrf.delete()
 
                 res, _ = Operations.objects.filter(id=id).delete()
+        return res
 
     def deleteFromRequest(self, request, removed=None):
+        from kaf_pas.planing.models.production_order import Production_order
+        from kaf_pas.planing.models.production_order import Production_orderManager
+        from kaf_pas.planing.models.operation_refs import Operation_refs
+        from kaf_pas.planing.models.production_order_opers import Production_order_opers
+        from kaf_pas.planing.models.production_order_opers import Production_order_opersManager
 
         request = DSRequest(request=request)
         res = 0
@@ -605,7 +711,24 @@ class Production_order_valuesManager(OperationsManager):
             ids.append(data.get('id'))
 
         with transaction.atomic():
-            Production_order_valuesManager.delete_sums(ids=ids)
+            record_ids = [a.parent.id for a in Operation_refs.objects.filter(parent__opertype__code=DETAIL_OPERS_PRD_TSK, child_id=data.get('id'))]
+
+            if Production_order_valuesManager.delete_sums(ids=ids) > 0:
+                tag = request.json.get('tag')
+                if tag != None:
+                    parent_record = tag.get('parentRecord')
+                    if parent_record != None:
+                        operation = Production_order.objects.get(id=parent_record)
+                        if operation.status.id == settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(doing).id:
+                            operation.status = settings.OPERS_TYPES_STACK.PRODUCTION_TASK_STATUSES.get(restarted)
+                            operation.save()
+
+                        records = [Production_order_opersManager.getRecord(record=record, user=request.user) for record in Production_order_opers.objects.filter(id__in=record_ids)]
+                        WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_operationsGrid_row, records=records)
+                        WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_grid_row, records=[Production_orderManager.getRecord(operation)])
+                        WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_operationsValues_grid)
+                        WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_item_grid)
+                        WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_buffers_grid)
 
         return res
 
