@@ -48,7 +48,8 @@ class Status_operation_typesManager(BaseRefManager):
     @staticmethod
     def make_statuses(opertype, status_map):
         res = dict()
-        settings.LOCKS.acquire('Status_operation_typesManager.make_statuses')
+        key = 'Status_operation_typesManager.make_statuses'
+        settings.LOCKS.acquire(key)
         with transaction.atomic():
             for key_value in status_map:
                 status, _ = Status_operation_types.objects.update_or_create(
@@ -61,8 +62,8 @@ class Status_operation_typesManager(BaseRefManager):
                         deliting=False,
                         editing=False,
                     ))
-                res.setdefault(key_value.get('code'), status)
-        settings.LOCKS.release('Status_operation_typesManager.make_statuses')
+                setAttr(res, key_value.get('code'), status)
+        settings.LOCKS.release(key)
         return res
 
     @staticmethod
@@ -92,7 +93,8 @@ class Status_operation_types(BaseRef):
 
     props = BitField(flags=(
         ('disabled', 'Неактивная запись в гриде'),
-        ('blink', 'Мигающее поле в гриде')
+        ('blink', 'Мигающее поле в гриде'),
+        ('bold', 'Жирное поле в гриде'),
     ), default=0, db_index=True)
 
     objects = Status_operation_typesManager()
