@@ -13,7 +13,7 @@ def Production_order_opers_per_demand_Fetch(request):
         DSResponse(
             request=request,
             data=Production_order_opers_per_demand.objects.
-                select_related().
+                select_related('demand', 'item', 'launch', 'parent_launch', 'color', 'edizm').
                 get_range_rows1(
                 request=request,
                 function=Production_order_opers_per_demandManager.getRecord
