@@ -20,5 +20,5 @@ class Command(BaseCommand):
         user_id = options.get('user_id')
 
         with transaction.atomic():
-            Ready_2_launchManager.make(demand=demand_id, user=user_id)
+            Ready_2_launchManager.make(demand_id=demand_id, user=user_id)
         print('Done')
