@@ -1,12 +1,13 @@
 import logging
 
+from bitfield import BitField
 from django.db import transaction
 from django.db.models import PositiveIntegerField
 from django.forms import model_to_dict
 
 from isc_common import delAttr, setAttr
 from isc_common.fields.description_field import DescriptionField
-from isc_common.fields.related import ForeignKeyProtect, ForeignKeySetNull
+from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
 from isc_common.models.base_ref import Hierarcy
@@ -22,17 +23,58 @@ logger = logging.getLogger(__name__)
 
 
 class Launch_operations_itemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    def create(self, **kwargs):
+        if kwargs.get('props') == None:
+            setAttr(kwargs, 'props', Launch_operations_item.props.created)
+        return super().create(**kwargs)
+
+    def update(self, **kwargs):
+        if kwargs.get('props') == None:
+            setAttr(kwargs, 'props', Launch_operations_item.props.updated)
+        return super().update(**kwargs)
+
+    def get_range_rows1(self, request, function=None, distinct_field_names=None, remove_fields=None):
+        request = DSRequest(request=request)
+        data = request.json.get('data')
+
+        launch_id = data.get('launch_id')
+        if launch_id != None:
+            parent = Launches.objects.get(id=launch_id).parent
+            if parent == None:
+                launch_id = [launch.id for launch in Launches.objects.filter(parent_id=launch_id)]
+                setAttr(data, 'launch_id', launch_id)
+                request.set_data(data=data)
+
+        self.alive_only = request.alive_only
+        self.enabledAll = request.enabledAll
+        res = self.get_range_rows(
+            start=request.startRow,
+            end=request.endRow,
+            function=function,
+            distinct_field_names=distinct_field_names,
+            json=request.json,
+            criteria=request.get_criteria(),
+            user=request.user
+        )
+        return res
 
 
 class Launch_operations_itemManager(CommonManagetWithLookUpFieldsManager):
 
+    @staticmethod
+    def props():
+        return BitField(flags=(
+            ('created', 'Операция добавлена'),  # 1
+            ('updated', 'Операция изменена'),  # 2
+        ), default=0, db_index=True)
+
     @staticmethod
     def getRecord(record):
         res = {
             'id': record.id,
             'launch_id': record.launch.id,
+            'launch__code': record.launch.code,
+            'launch__date': record.launch.date,
             'operation_id': record.operation.id,
             'operationitem_id': record.operationitem.id if record.operationitem else None,
             'operation__code': record.operation.code,
@@ -140,18 +182,38 @@ class Launch_operations_item(Hierarcy):
     item = ForeignKeyProtect(Item)
     launch = ForeignKeyProtect(Launches)
     num = PositiveIntegerField(db_index=True, default=None)
+    old_num = PositiveIntegerField(db_index=True, null=True, blank=True)
     operation = ForeignKeyProtect(Operations)
-    operationitem = ForeignKeySetNull(Operations_item, null=True, blank=True)
+    operationitem = ForeignKeyProtect(Operations_item)
+    props = Launch_operations_itemManager.props()
     qty = PositiveIntegerField(null=True, blank=True, db_index=True)
 
     objects = Launch_operations_itemManager()
 
     def __str__(self):
-        return f"ID:{self.id}, item: [{self.item}], id_izm: [{self.ed_izm}], qty: {self.qty}, num: {self.num}"
+        return f"ID:{self.id}, " \
+               f"old_num: {self.old_num}, " \
+               f"num: {self.num}, " \
+               f"operation: [{self.operation}], " \
+               f"operationitem: [{self.operationitem}], " \
+               f"qty: {self.qty}, " \
+               f"props: {self.props}"
+
+
+        # return f"ID:{self.id}, \n" \
+        #        f"item: [{self.item}], \n" \
+        #        f"id_izm: [{self.ed_izm}], \n" \
+        #        f"item: [{self.item}], \n" \
+        #        f"operation: [{self.operation}], \n" \
+        #        f"operationitem: [{self.operationitem}], \n" \
+        #        f"qty: {self.qty}, \n" \
+        #        f"props: {self.props}, \n" \
+        #        f"old_num: {self.old_num}, \n" \
+        #        f"num: {self.num}"
 
     def __repr__(self):
         return self.operation.full_name
 
     class Meta:
         verbose_name = 'Кросс таблица'
-        unique_together = (('item', 'launch', 'operation', 'num'),)
+        unique_together = (('item', 'launch', 'operation', 'num', 'operationitem'),)
