@@ -59,7 +59,7 @@ class Operations(BaseRefHierarcy):
     objects = OperationsManager()
 
     def __str__(self):
-        return f'ID={self.id}, code={self.code}, name={self.name}, description={self.description}'
+        return f'ID={self.id}, code={self.code}, name={self.name}, full_name={self.full_name}, description={self.description}'
 
     class Meta:
         verbose_name = 'Операции'
