@@ -29,6 +29,7 @@ class Operations_template_resourceQuerySet(CommonManagetWithLookUpFieldsQuerySet
 
         if not kwargs.get('resource_id') and not kwargs.get('location_id'):
             raise Exception('Необходим хотябы один выбранный параметр.')
+
         delAttr(kwargs, 'resource__name')
         delAttr(kwargs, 'location__full_name')
 
@@ -47,7 +48,8 @@ class Operations_template_resourceManager(CommonManagetWithLookUpFieldsManager):
 
     @staticmethod
     def refresh_resource(apps=None, schema_editor=None):
-        settings.LOCKS.acquire('Operations_template_resourceManager.refresh_resource')
+        key = 'Operations_template_resourceManager.refresh_resource'
+        settings.LOCKS.acquire(key)
         sql_text = '''select  template_id, count(*)
                     from production_operations_template_resource
                     group by template_id
@@ -76,7 +78,7 @@ class Operations_template_resourceManager(CommonManagetWithLookUpFieldsManager):
                             # print(res)
                         else:
                             first_step = False
-        settings.LOCKS.release('Operations_template_resourceManager.refresh_resource')
+        settings.LOCKS.release(key)
 
     def createFromRequest(self, request):
         request = DSRequest(request=request)
@@ -96,6 +98,7 @@ class Operations_template_resourceManager(CommonManagetWithLookUpFieldsManager):
                     if created:
                         _res = model_to_dict(operation_resource)
                         setAttr(_res, 'location__full_name', operation_resource.location.full_name if operation_resource.location else None)
+                        setAttr(_res, 'location_fin__full_name', operation_resource.location_fin.full_name if operation_resource.location_fin else None)
                         setAttr(_res, 'resource__name', operation_resource.resource.full_name if operation_resource.resource else None)
                         res.append(_res)
         else:
@@ -105,6 +108,7 @@ class Operations_template_resourceManager(CommonManagetWithLookUpFieldsManager):
             if created:
                 _res = model_to_dict(operation_resource)
                 setAttr(_res, 'location__full_name', operation_resource.location.full_name if operation_resource.location else None)
+                setAttr(_res, 'location_fin__full_name', operation_resource.location_fin.full_name if operation_resource.location_fin else None)
                 setAttr(_res, 'resource__name', operation_resource.resource.full_name if operation_resource.resource else None)
                 res.append(_res)
         return res
@@ -115,6 +119,9 @@ class Operations_template_resourceManager(CommonManagetWithLookUpFieldsManager):
         data = request.get_data()
 
         self._remove_prop(data, removed)
+        if data.get('location_fin_id') == None:
+            location = Locations.objects.get(id=data.get('location_fin__code'))
+            setAttr(data, 'location_fin_id', location.id)
         _data = self.clone_data(data)
         delAttr(_data, 'id')
         res = super().filter(id=data.get('id')).update(**_data)
@@ -132,6 +139,10 @@ class Operations_template_resourceManager(CommonManagetWithLookUpFieldsManager):
             'location__code': record.location.code if record.location else None,
             'location__name': record.location.name if record.location else None,
             'location__full_name': record.location.full_name if record.location else None,
+            'location_fin_id': record.location_fin.id if record.location_fin else None,
+            'location_fin__code': record.location_fin.code if record.location_fin else None,
+            'location_fin__name': record.location_fin.name if record.location_fin else None,
+            'location_fin__full_name': record.location_fin.full_name if record.location_fin else None,
             'complex_name': record.complex_name,
             'batch_size': record.batch_size,
             'editing': record.editing,
@@ -146,7 +157,8 @@ class Operations_template_resourceManager(CommonManagetWithLookUpFieldsManager):
 class Operations_template_resource(AuditModel):
     template = OneToOneField(Operations_template_detail, on_delete=CASCADE)
     resource = ForeignKeyProtect(Resource, null=True, blank=True)
-    location = ForeignKeyProtect(Locations, null=True, blank=True)
+    location = ForeignKeyProtect(Locations, null=True, blank=True, related_name='Operations_template_resource_location')
+    location_fin = ForeignKeyProtect(Locations, null=True, blank=True, related_name='Operations_template_resource_location_fin')
     batch_size = PositiveIntegerField(default=1)
 
     @property
@@ -164,8 +176,12 @@ class Operations_template_resource(AuditModel):
     class Meta:
         verbose_name = 'Кросс таблица'
         constraints = [
-            UniqueConstraint(fields=['template'], condition=Q(location=None) & Q(resource=None), name='Operations_template_resource_unique_constraint_0'),
-            UniqueConstraint(fields=['template', 'resource'], condition=Q(location=None), name='Operations_template_resource_unique_constraint_1'),
-            UniqueConstraint(fields=['location', 'template'], condition=Q(resource=None), name='Operations_template_resource_unique_constraint_2'),
-            UniqueConstraint(fields=['location', 'template', 'resource'], name='Operations_template_resource_unique_constraint_3'),
+            UniqueConstraint(fields=['template'], condition=Q(location=None) & Q(location_fin=None) & Q(resource=None), name='Operations_template_resource_unique_constraint_0'),
+            UniqueConstraint(fields=['resource', 'template'], condition=Q(location=None) & Q(location_fin=None), name='Operations_template_resource_unique_constraint_1'),
+            UniqueConstraint(fields=['location', 'template'], condition=Q(location_fin=None) & Q(resource=None), name='Operations_template_resource_unique_constraint_2'),
+            UniqueConstraint(fields=['location', 'resource', 'template'], condition=Q(location_fin=None), name='Operations_template_resource_unique_constraint_3'),
+            UniqueConstraint(fields=['location_fin', 'template'], condition=Q(location=None) & Q(resource=None), name='Operations_template_resource_unique_constraint_4'),
+            UniqueConstraint(fields=['location_fin', 'resource', 'template'], condition=Q(location=None), name='Operations_template_resource_unique_constraint_5'),
+            UniqueConstraint(fields=['location', 'location_fin', 'template'], condition=Q(resource=None), name='Operations_template_resource_unique_constraint_6'),
+            UniqueConstraint(fields=['location', 'location_fin', 'resource', 'template'], name='Operations_template_resource_unique_constraint_7'),
         ]
