@@ -22,6 +22,10 @@ def Ready_2_launch_Fetch(request):
 def Ready_2_launch_Add(request):
     return JsonResponse(DSResponseAdd(data=Ready_2_launch.objects.createFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
 
+@JsonResponseWithException()
+def Ready_2_launch_Reculc(request):
+    return JsonResponse(DSResponseAdd(data=Ready_2_launch.objects.reculcFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
+
 
 @JsonResponseWithException()
 def Ready_2_launch_Update(request):
